//--------------------------------------------------------------------------------------
// Order Independent Transparency Fragment Shader
//
// Author: Louis Bavoil
// Email: sdkfeedback@nvidia.com
//
// Copyright (c) NVIDIA Corporation. All rights reserved.
//--------------------------------------------------------------------------------------

uniform float Alpha;
uniform float transp;

#define COLOR_FREQ 30.0
#define ALPHA_FREQ 30.0

//#if 1

varying vec3 jpWorld;
varying vec3 jpNormal;
varying vec3 jpObject;
varying vec2 jpTexCoord;
varying vec4 vertColor;

vec3 getLight(){
	vec3 normal = jpNormal;
	//normal.z = abs(normal.z);
	
	if(!gl_FrontFacing)
		normal = -normal;

	vec3 lightVec0 = normalize(vec3(gl_LightSource[0].position) - jpWorld);
	vec3 lightVec1 = normalize(vec3(gl_LightSource[1].position) - jpWorld);
	float intensity0 = dot(lightVec0, normal);
	float intensity1 = dot(lightVec1, normal);

	if(intensity0 < 0) intensity0 = 0;
	if(intensity1 < 0) intensity1 = 0;

	vec3 light0 = vec3(gl_LightSource[0].ambient) + vec3(gl_LightSource[0].diffuse)*intensity0;
	vec3 light1 = vec3(gl_LightSource[1].ambient) + vec3(gl_LightSource[1].diffuse)*intensity1;

	return (light0 + light1);
}

vec4 ShadeFragment()
{
	vec3 normal = jpNormal;
	//vec3 cam = vec3(gl_ModelViewMatrix[0][3], gl_ModelViewMatrix[1][3], gl_ModelViewMatrix[2][3]);
	//vec3 ray - vec3(cam - jpWorld);
	vec4 fragColor;
	//jpNormal.z = abs(jpNormal.z);
	if(!gl_FrontFacing)
		normal = -normal;

	vec3 ray = vec3(0,0,1);
	float cosGamma = dot(ray, normal);
	float alpha = clamp(vertColor.a/cosGamma, 0.01, 1.0);
	
	//float i = floor(jpObject.x * COLOR_FREQ);
	//float j = floor(jpObject.y * ALPHA_FREQ);
	//vec3 color = (fmod(i, 2.0) == 0) ? vec3(.4,.85,.0) : vec3(1.0);
	//vec3 color = vec3(.5, .5, .5);

	//if(!gl_FrontFacing)
		//color = vec3(.3, .3, 1.0);
	//else
	//	color = vec3(.3, 1.0, .3);
	
	vec3 color = vertColor.xyz;

	float light = .5+.5*length(getLight());
	fragColor = vec4(clamp(light*color, 0.0, 1.0), alpha);

//	fragColor = vec4(float(transp), 0, 0, 1);
	return fragColor;
}

/*#elif 0
vec4 ShadeFragment()
{
	float xWorldPos = gl_TexCoord[0].x;
	float yWorldPos = gl_TexCoord[0].y;
	float diffuse = gl_TexCoord[0].z;

	vec4 color;
	float i = floor(xWorldPos * COLOR_FREQ);
	float j = floor(yWorldPos * ALPHA_FREQ);
	color.rgb = (fmod(i, 2.0) == 0) ? vec3(.4,.85,.0) : vec3(1.0);
	//color.a = (fmod(j, 2.0) == 0) ? Alpha : 0.2;
	color.a = Alpha;

	color.rgb *= diffuse;
	return color;
}
#else
vec4 ShadeFragment()
{
	vec4 color;
	color.rgb = vec3(.4,.85,.0);
	color.a = Alpha;
	return color;
}
#endif*/
